from numpy.random import permutation
from sklearn import svm, datasets
from sacred import Experiment

ex = Experiment('iris_rbf_svm')

from sacred_integration import NeptuneObserver

ex.observers.append(NeptuneObserver(project_name='jakub-czakon/examples'))


@ex.config
def cfg():
    C = 1.0
    gamma = 0.7


@ex.automain
def run(C, gamma, _run):
    for i in range(100):
        _run.log_scalar("training.accuracy", i)

    iris = datasets.load_iris()
    per = permutation(iris.target.size)
    iris.data = iris.data[per]
    iris.target = iris.target[per]
    clf = svm.SVC(C, 'rbf', gamma=gamma)
    clf.fit(iris.data[:90],
            iris.target[:90])
    return clf.score(iris.data[90:],
                     iris.target[90:])
